﻿Type=Class
Version=3.5
@EndOfDesignText@
'Class module
Sub Class_Globals

	Type CountryPolygon( _
		Geometry As JTS_Geometry, _
		Name As String)

	Private DATABASE_FILENAME As String="ne_110m_admin_0_countries.sqlite"
	Private DATABASE_PATH As String=File.DirDefaultExternal
	'	SRID is the 'spatial reference id', a value of 4326 corresponds to WGS84 projection
	Public SRID As Int=4326
	Private TABLE_NAME As String="ne_110m_admin_0_countries"
	
	Private SpatialiteConstants As Spatialite_Constants
	Private SpatialiteDatabase As Spatialite_Database
	Private WKBReader1 As JTS_WKBReader
End Sub

Public Sub Initialize

	If Not(File.Exists(DATABASE_PATH, DATABASE_FILENAME)) Then
		File.Copy(File.DirAssets, DATABASE_FILENAME, DATABASE_PATH, DATABASE_FILENAME)
	End If
	
	SpatialiteDatabase.Initialize
	SpatialiteDatabase.Open(DATABASE_PATH, DATABASE_FILENAME, SpatialiteConstants.SQLITE_OPEN_READONLY)
	WKBReader1.Initialize
End Sub

Public Sub Close
	SpatialiteDatabase.Close
End Sub

Public Sub GetCountryNames As List
	Dim CountryNames As List
	Dim SpatialiteStatement As Spatialite_Stmt
	
	CountryNames.Initialize
	SpatialiteStatement=SpatialiteDatabase.Prepare("SELECT name FROM "&TABLE_NAME&" ORDER BY name ASC")
	Do While SpatialiteStatement.Step
		CountryNames.Add(SpatialiteStatement.ColumnString(0))
	Loop
	SpatialiteStatement.Close
	Return CountryNames
End Sub

Public Sub GetCountryPolygon(CountryName As String) As CountryPolygon
	Dim CountryPolygon1 As CountryPolygon
	Dim SpatialiteStatement As Spatialite_Stmt
	
	Log(CountryName)
	
	SpatialiteStatement=SpatialiteDatabase.Prepare("SELECT AsBinary(ST_Transform(Geometry, ?)) AS CountryPolygon FROM "&TABLE_NAME&" WHERE name=?")
	SpatialiteStatement.BindInt(1, SRID)
	SpatialiteStatement.BindString(2, CountryName)
	
	If SpatialiteStatement.Step Then
		CountryPolygon1.Initialize
		CountryPolygon1.Name=CountryName
		CountryPolygon1.Geometry=WKBReader1.Read(SpatialiteStatement.ColumnBytes(0))
	End If
	
	Return CountryPolygon1
End Sub
